
<p align="center">
    <a href="LICENSE">
        <img src="https://img.shields.io/github/license/sentilis/tona?style=flat-square" />
    </a>
    <a href=".pm/version.yml">
        <img src="https://img.shields.io/badge/dynamic/yaml?color=green&label=version&query=version.*&url=https://raw.githubusercontent.com/sentilis/tona/main/.pm/version.yml">
    </a>
    <a href=".pm/version.yml">
        <img src="https://img.shields.io/badge/dynamic/yaml?color=green&label=prerelease&query=prerelease.*&url=https://raw.githubusercontent.com/sentilis/tona/main/.pm/version.yml"/>
    </a>
</p>

## TONA

### What's TONA? 
It is an ALL IN ONE tool that will help increase your personal productivity. 

Our goal is to create a lightweight tool with a minimalist interface, so that users can focus on what matters most.

### Tools

* ⌛️ Time Tracking
* 📑 Project Manager
* 🎯 Habit Manager
* 🚀 OKR Manager

Incoming

* Contacts
* Wallet
* Password Manager

## Getting started

### Install using pip

```bash
$ pip install -U tona
$ tona webapp
$ Running on http://0.0.0.0:5001/ (Press CTRL+C to quit
```

### Install using docker-compose

```bash
$ docker-compose up
$ Running on http://0.0.0.0:5001/ (Press CTRL+C to quit
```

## Contribute

We invite you to try out `tona` and file any issues at github issues page. Patches are most welcome!


## Links
- Issues: https://github.com/sentilis/tona/issues
- Discussions: https://github.com/sentilis/tona/discussions